#
# spec file for package ghc-blaze-markup
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name blaze-markup
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.8.3.0
Release:        3.1
Summary:        A blazingly fast markup combinator library for Haskell
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-blaze-builder-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Core modules of a blazingly fast markup combinator library for the Haskell
programming language. The Text.Blaze module is a good starting point, as well
as this tutorial: <http://jaspervdj.be/blaze/tutorial.html>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Jul  4 2024 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.3.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Sep 29 2023 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.3.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Sep 25 2023 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.3.0.
  - 0.8.3.0 (2023-09-25)
  * Add `ToMarkup` and `ToValue` instances for `NonEmpty Char`
  * Bump `bytestring` upper bound to 0.13
  * Bump `text` upper bound to 2.1
* Sun Jul 16 2023 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.2.8 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar 15 2023 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.2.8 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Aug 15 2022 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.2.8 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Feb  3 2022 Peter Simons <psimons@suse.com>
- Update blaze-markup to version 0.8.2.8 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update blaze-markup to version 0.8.2.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar  4 2021 psimons@suse.com
- Update blaze-markup to version 0.8.2.8.
  - 0.8.2.8 (2021-03-04)
  * Bump `base` upper bound to 4.16
  * Bump `tasty` upper bound to 1.5
  * Bump `bytestring` upper bound to 0.12
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jul  1 2020 psimons@suse.com
- Update blaze-markup to version 0.8.2.7.
  - 0.8.2.7 (2020-06-30)
  * Bump Cabal version lower bound to 1.10
  - 0.8.2.6 (2020-06-30)
  * Bump `tasty` upper bound to 1.4
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update blaze-markup to version 0.8.2.5.
  - 0.8.2.5 (2020-04-20)
  * Bump `base` upper bound to 4.15
  - 0.8.2.4 (2020-03-29)
  * Bump `QuickCheck` upper bound to 2.15
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Oct  3 2019 psimons@suse.com
- Update blaze-markup to version 0.8.2.3.
  - 0.8.2.3 (2019-10-02)
  * Bump `base` to 4.13
  * Bump `tasty` to 1.2
  * Bump `QuickCheck` to 2.13
* Sat Jan 19 2019 Peter Simons <psimons@suse.com>
- Update Cabal build instructions for more accurate dependencies.
* Thu Oct  4 2018 psimons@suse.com
- Update blaze-markup to version 0.8.2.2.
  - 0.8.2.2 (2018-09-25)
  * Bump `base` to 4.12
  * Bump `containers` to 0.6
  * Bump `tasty` to 1.1
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update blaze-markup to version 0.8.2.1.
  * Define `ToMarkup` instance for `Natural`.
  * Compatibility with Semigroup/Monoid proposal
  * Switch to `tasty` for running tests
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.8.0.0.
* Sun Dec  4 2016 psimons@suse.com
- Update to version 0.7.1.1 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.7.1.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.7.0.3 revision 0 with cabal2obs.
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 0.7.0.3
  * Relax `HUnit` dependency to allow 1.3
* Mon Apr 20 2015 mimi.vx@gmail.com
- update to 0.7.0.2
  * Add combinators to insert HTML comments
  * Add `Applicative` instance for `MarkupM`
* Sun Nov  9 2014 peter.trommler@ohm-hochschule.de
- update to 0.6.1.1
  * Bump `text` dependency to allow 1.2 (Haskell Platform 2014.2.0.0)
  * Add the `null` query to Text.Blaze.Internal.
  * Add the operator (!?) for nicely setting conditional attributes
* Mon Oct 21 2013 sbahling@suse.com
- add %%defattr(-,root,root,-) to devel section
* Tue May 14 2013 peter.trommler@ohm-hochschule.de
- update to 0.5.1.5 from upstream (no changelog)
* Sun Nov 18 2012 peter.trommler@ohm-hochschule.de
- update to 0.5.1.1 from upstream
  * relax version dependencies
* Mon May  7 2012 peter.trommler@ohm-hochschule.de
- Initial packaging: spec file template generated by cabal2spec-0.25.5
